///File : MainFrame.cpp
//------------------------------------------------------------------------------
/*
    This file is part of forbidden2forget.

    Forbidden2forget is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Forbidden2forget is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with forbidden2forget.  If not, see <http://www.gnu.org/licenses/>.
*/
//------------------------------------------------------------------------------
#include "MainFrame.hpp"
#include "Printing.hpp"
#include "findFile.hpp"
//------------------------------------------------------------------------------
BEGIN_EVENT_TABLE(MainFrame, wxFrame)
    EVT_CLOSE(MainFrame::OnFrameClose)
END_EVENT_TABLE()

//------------------------------------------------------------------------------
void MainFrame::EnableMenus(bool enable)
{
    m_MenuItemSave->Enable(enable);
    m_MenuItemChgPassword->Enable(enable);
    m_MenuItemClose->Enable(enable);
    m_MenuItemPrintPreview->Enable(enable);
    m_MenuItemPrint->Enable(enable);
}
//------------------------------------------------------------------------------
MainFrame::MainFrame(const wxString& title, const wxPoint& pos, const wxSize& size, long style) : wxFrame(NULL, -1, title, pos, size, style)
{
    wxString ImgFileName;
    // Presentation général
    #if defined(__WXMSW__)
        SetIcon(wxIcon(_T("monicone")));
    #elif defined(__UNIX__)
        ImgFileName = findFile(_T("data/icon.png"));
        if(wxFileExists(ImgFileName))
        {
            SetIcon(wxIcon(ImgFileName, wxBITMAP_TYPE_PNG));
        }
    #endif //#ifdef WIN32
    SetBackgroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_BTNFACE));

    // Menus
    wxMenu *NewMenu = new wxMenu;
    NewMenu->Append(Id_NewLvl5e, _("Level &5th"));
    NewMenu->Append(Id_NewLvl4e, _("Level &4th"));
    NewMenu->Append(Id_NewLvl3e, _("Level &3th"));
    NewMenu->Append(Id_NewLvl2nd, _("Level &2nd"));

    m_FileMenu = new wxMenu;
    m_FileMenu->Append(wxID_NEW, _("&New") , NewMenu);
    m_FileMenu->Append(wxID_OPEN, _("&Open"));
    m_MenuItemSave = m_FileMenu->Append(wxID_SAVE, _("&Save"));
    m_FileMenu->AppendSeparator();
    m_MenuItemPrint = m_FileMenu->Append(wxID_PRINT, _("&Print"));
    m_MenuItemPrintPreview = m_FileMenu->Append(wxID_PREVIEW, _("Print previe&w"));
    m_FileMenu->AppendSeparator();
    m_MenuItemClose = m_FileMenu->Append(wxID_CLOSE, _("&Close"));

    m_MenuItemChgPassword = new wxMenuItem(m_FileMenu, Id_ChgPassword, _("&Change the password\tCtrl+C"));
    ImgFileName = findFile(_T("data/key.png"));
    if(wxFileExists(ImgFileName))
    {
        wxImage img(ImgFileName, wxBITMAP_TYPE_PNG);
        m_MenuItemChgPassword->SetBitmap(wxBitmap(img));
    }
    m_FileMenu->Append(m_MenuItemChgPassword);

    m_FileMenu->AppendSeparator();
    m_FileMenu->Append(wxID_EXIT, _("&Quit"));


    m_HelpMenu = new wxMenu;
    m_HelpMenu->Append(wxID_ABOUT, _("&About"));

    m_MenuBar = new wxMenuBar();
    m_MenuBar->Append(m_FileMenu,_("&File"));
    m_MenuBar->Append(m_HelpMenu,_("&Help"));

    SetMenuBar(m_MenuBar);

    // Corp
	wxBoxSizer* MainSizer = new wxBoxSizer( wxVERTICAL );

    m_MainNotebook = new wxNotebook(this, wxID_ANY);
    MainSizer->Add(m_MainNotebook, 1, wxEXPAND);

    m_MyPanelStats = new PanelStats(m_MainNotebook, wxID_ANY, this);
    m_MainNotebook->AddPage(m_MyPanelStats, _("Stats"));

    m_MyPanelVerbs = new PanelVerbs(m_MainNotebook, wxID_ANY, this);
    m_MainNotebook->AddPage(m_MyPanelVerbs, _("Verbs"), true);

	this->SetSizer( MainSizer );

    this->Connect( wxID_EXIT, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(MainFrame::OnQuit));
    this->Connect( wxID_ABOUT, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(MainFrame::OnAbout));
    this->Connect( wxID_OPEN, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(MainFrame::OnOpen));
    this->Connect( wxID_SAVE, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(MainFrame::OnSave));
    this->Connect( Id_ChgPassword, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(MainFrame::OnChgPassword));
    this->Connect( wxID_CLOSE, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(MainFrame::OnClose));
    this->Connect( wxID_PREVIEW, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(MainFrame::OnPrintPreview));
    this->Connect( wxID_PRINT, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(MainFrame::OnPrint));

    this->Connect( Id_NewLvl5e, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(MainFrame::OnNew5e));
    this->Connect( Id_NewLvl4e, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(MainFrame::OnNew4e));
    this->Connect( Id_NewLvl3e, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(MainFrame::OnNew3e));
    this->Connect( Id_NewLvl2nd, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler(MainFrame::OnNew2nd));
}
//------------------------------------------------------------------------------
void MainFrame::OnQuit(wxCommandEvent& WXUNUSED(event))
{
    m_MyPanelVerbs->OnFrameClose();
    exit (EXIT_SUCCESS);
}
//------------------------------------------------------------------------------
void MainFrame::OnAbout(wxCommandEvent& WXUNUSED(event))
{
    DialogAbout MyDialogAbout(this, wxID_ANY);
    MyDialogAbout.ShowModal();
}

//------------------------------------------------------------------------------
void MainFrame::OnOpen(wxCommandEvent& event)
{
    m_MyPanelVerbs->OnOpen();
}
//------------------------------------------------------------------------------

void MainFrame::OnSave(wxCommandEvent& event)
{
    m_MyPanelVerbs->OnSave();
}
//------------------------------------------------------------------------------

void MainFrame::OnChgPassword(wxCommandEvent& event)
{
    m_MyPanelVerbs->OnChgPassword();
}
//------------------------------------------------------------------------------

void MainFrame::OnClose(wxCommandEvent& event)
{
    m_MyPanelVerbs->OnClose();
}
//------------------------------------------------------------------------------

void MainFrame::OnFrameClose(wxCloseEvent& event)
{
    m_MyPanelVerbs->OnFrameClose();
    event.Skip();
}
//------------------------------------------------------------------------------
void MainFrame::RefreshPanelStats()
{
    m_MyPanelStats->Refresh();
}
//------------------------------------------------------------------------------
F2fVerbs* MainFrame::GetF2fVerbs()
{
    return &m_F2fVerbs;
}
//------------------------------------------------------------------------------
void MainFrame::ResetBiginWorkDateTime()
{
    m_BiginWorkDateTime.SetToCurrent();
}
//------------------------------------------------------------------------------
wxDateTime MainFrame::GetBiginWorkDateTime()
{
    return m_BiginWorkDateTime;
}

//------------------------------------------------------------------------------
void MainFrame::LoadFile(wxString fileName)
{
    m_MyPanelVerbs->OnOpen(fileName);
}

//------------------------------------------------------------------------------
void MainFrame::OnPrintPreview(wxCommandEvent& event)
{
    wxPrintPreview *myPrintPreview = new wxPrintPreview(new ScorePrintout(this, _T("Scores")), new ScorePrintout(this, _T("Scores")), new wxPrintData);
    if(!myPrintPreview->Ok())
    {
        delete myPrintPreview;
        wxMessageBox(_T("There was a problem previewing.\nPerhaps your current printer is not set correctly?"), _T("Previewing"), wxOK);
        return;
    }

    wxPreviewFrame *myPreviewFrame = new wxPreviewFrame(myPrintPreview, this, _("Preview"));
    myPreviewFrame->Centre(wxBOTH);
    myPreviewFrame->Initialize();
    myPreviewFrame->Show();
}

//------------------------------------------------------------------------------
void MainFrame::OnPrint(wxCommandEvent& event)
{
    wxPrintData printData;
    wxPrintDialogData printDialogData(printData);

    wxPrinter printer(& printDialogData);
    ScorePrintout printout(this, _T("Scores"));
    if (!printer.Print(this, &printout, true /*prompt*/))
    {
        if (wxPrinter::GetLastError() == wxPRINTER_ERROR)
        wxMessageBox(_T("There was a problem printing.\nPerhaps your current printer is not set correctly?"), _T("Printing"), wxOK);
    }
    else
    {
        printData = printer.GetPrintDialogData().GetPrintData();
    }
}

//------------------------------------------------------------------------------
void MainFrame::OnNew5e(wxCommandEvent& event){m_MyPanelVerbs->OnNew(5);}
void MainFrame::OnNew4e(wxCommandEvent& event){m_MyPanelVerbs->OnNew(4);}
void MainFrame::OnNew3e(wxCommandEvent& event){m_MyPanelVerbs->OnNew(3);}
void MainFrame::OnNew2nd(wxCommandEvent& event){m_MyPanelVerbs->OnNew(2);}

